==> tine20-allinone_2020.08.8.tar.bz2: Timetracker/js/Timetracker-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Хронометраж"

, "summary"
: "резюме"

, "Total Timesheets"
: "Все табели"

, "Billable Timesheets"
: "Оплачиваемые табели"

, "Total Time"
: "Все время"

, "Time of Billable Timesheets"
: "Время оплачиваемых табелей"

, "Description"
: "Описание"

, "Detail"
: "Подробности"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Экспорт расписания"

, "Export as ODS"
: "Экспорт как ODS"

, "Export as CSV"
: "Экспорт как CSV"

, "Export as ..."
: "Экспорт в ..."

, "Timesheet, Timesheets"
: [
  "Табель"
 ,"Табеля"
 ,"Табелей"
 ,"Табелей"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Failed"
: "Не удалось"

, "Could not save {0}."
: "Не сохранено {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Договор"

, "without contract"
: "без договора"

, "Add New Timeaccount"
: ""

, "Unit"
: "Часть"

, "Unit Price"
: "Цена на части"

, "Factor"
: ""

, "Budget"
: "Бюджет"

, "Status"
: "Статус"

, "closed"
: "Закрыто"

, "open"
: "Открыто"

, "Cleared In"
: "Рассчитан в"

, "Cleared at"
: "Создано"

, "Cost Center"
: "Затраты"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Табели оплачиваемы"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Временный счет"
 ,"Временных счета"
 ,"Временных счетов"
 ,"Временных счетов"

]
, "Number"
: "Номер"

, "Title"
: "Заголовок"

, "Access"
: "Доступ"

, "Permissions"
: "Права доступа"

, "Time Account - Billed"
: ""

, "not yet billed"
: "еще не оплачено"

, "to bill"
: "оплатить"

, "billed"
: "оплачено"

, "Time Account - Status"
: "Статус временного счета"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Забронировать собственное"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Показать все"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Закажите все"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Сделать рассчитываемым"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Показать закрытые"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "по умолчанию"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "Нет"

, "last week"
: "На прошлой неделе"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Рассчитан в"

, "Billed"
: "Оплачено"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Счет"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Оплачиваемо"

, "Cleared"
: "Просчитано"

, "Date"
: "Дата"

, "Start time"
: "Время старта"

, "End time"
: ""

, "Duration"
: "Продолжительность"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Счет времени закрыт"

, "Timetracker"
: "Хронометраж"

, "Timeaccounts to bill"
: "Расписание на оплату"

, "Timeaccounts not yet billed"
: "Расписание не оплачено"

, "Timeaccounts already billed"
: "Расписание оплачено"

, "My Timesheets today"
: "Моё расписание на сегодня"

, "My Timesheets this week"
: "Моё расписание на эту неделю"

, "My Timesheets last week"
: "Моё расписание на последнюю неделю"

, "My Timesheets this month"
: "Моё расписание на этот месяц"

, "My Timesheets last month"
: "Моё расписание на прошлый месяц"

, "Manage timeaccounts"
: "Управлять счетами времени"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: "Добавить временную учётную запись"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: "Управление общими избранными расписаниями"

, "Create or update shared timesheet favorites"
: "Создать или обновить общие временные расписания"






, "Timesheet"
: "Табель"

, "Timeaccount"
: ""

, "Time Account"
: "Временный счет"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Timetracker/js/Timetracker-lang-ru-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "Хронометраж"

, "summary"
: "резюме"

, "Total Timesheets"
: "Все табели"

, "Billable Timesheets"
: "Оплачиваемые табели"

, "Total Time"
: "Все время"

, "Time of Billable Timesheets"
: "Время оплачиваемых табелей"

, "Description"
: "Описание"

, "Detail"
: "Подробности"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: "Экспорт расписания"

, "Export as ODS"
: "Экспорт как ODS"

, "Export as CSV"
: "Экспорт как CSV"

, "Export as ..."
: "Экспорт в ..."

, "Timesheet, Timesheets"
: [
  "Табель"
 ,"Табеля"
 ,"Табелей"
 ,"Табелей"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""
 ,""
 ,""

]
, "Failed"
: "Не удалось"

, "Could not save {0}."
: "Не сохранено {0}."

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: "Договор"

, "without contract"
: "без договора"

, "Add New Timeaccount"
: ""

, "Unit"
: "Часть"

, "Unit Price"
: "Цена на части"

, "Factor"
: ""

, "Budget"
: "Бюджет"

, "Status"
: "Статус"

, "closed"
: "Закрыто"

, "open"
: "Открыто"

, "Cleared In"
: "Рассчитан в"

, "Cleared at"
: "Создано"

, "Cost Center"
: "Затраты"

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Табели оплачиваемы"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Временный счет"
 ,"Временных счета"
 ,"Временных счетов"
 ,"Временных счетов"

]
, "Number"
: "Номер"

, "Title"
: "Заголовок"

, "Access"
: "Доступ"

, "Permissions"
: "Права доступа"

, "Time Account - Billed"
: ""

, "not yet billed"
: "еще не оплачено"

, "to bill"
: "оплатить"

, "billed"
: "оплачено"

, "Time Account - Status"
: "Статус временного счета"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""
 ,""
 ,""

]
, "Book Own"
: "Забронировать собственное"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Показать все"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Закажите все"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Сделать рассчитываемым"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""
 ,""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Показать закрытые"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: "по умолчанию"

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: "Нет"

, "last week"
: "На прошлой неделе"

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Рассчитан в"

, "Billed"
: "Оплачено"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "Stream"
: ""

, "hour"
: ""

, "Account"
: "Счет"

, "Time Account (Number - Title)"
: ""

, "Project time billable"
: ""

, "Project time billable (combined)"
: ""

, "Billable"
: "Оплачиваемо"

, "Project time cleared in"
: ""

, "Project time Invoice"
: ""

, "Project time is cleared"
: ""

, "Projecttime cleared (combined)"
: ""

, "Date"
: "Дата"

, "Start time"
: "Время старта"

, "End time"
: ""

, "Duration"
: "Продолжительность"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Timetracker"
: "Хронометраж"

, "My Timesheets today"
: "Моё расписание на сегодня"

, "My Timesheets this week"
: "Моё расписание на эту неделю"

, "My Timesheets last week"
: "Моё расписание на последнюю неделю"

, "My Timesheets this month"
: "Моё расписание на этот месяц"

, "My Timesheets last month"
: "Моё расписание на прошлый месяц"

, "Timeaccounts to bill"
: "Расписание на оплату"

, "Timeaccounts not yet billed"
: "Расписание не оплачено"

, "Timeaccounts already billed"
: "Расписание оплачено"

, "Manage timeaccounts"
: "Управлять счетами времени"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: "Добавить временную учётную запись"

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: "Управление общими избранными расписаниями"

, "Create or update shared timesheet favorites"
: "Создать или обновить общие временные расписания"








, "Timesheet"
: "Табель"

, "Timeaccount"
: ""

, "Time Account"
: "Временный счет"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
